# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Cloudsave Service."""

__version__ = "3.20.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .put_game_record_concurr_33e39a import PutGameRecordConcurrentHandlerV1
from .put_player_public_recor_3f1a7f import PutPlayerPublicRecordConcurrentHandlerV1
from .put_player_record_concu_385e05 import PutPlayerRecordConcurrentHandlerV1
