# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Cloudsave Service."""

__version__ = "3.20.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_bulk_get_player_r_82c596 import AdminBulkGetPlayerRecordsByUserIDsHandlerV1
from .admin_bulk_put_player_r_27d5a1 import AdminBulkPutPlayerRecordsByKeyHandlerV1
from .admin_delete_player_pub_f11fd7 import AdminDeletePlayerPublicRecordHandlerV1
from .admin_delete_player_rec_168241 import AdminDeletePlayerRecordHandlerV1
from .admin_get_player_public_f015b6 import AdminGetPlayerPublicRecordHandlerV1
from .admin_get_player_record_b37faa import AdminGetPlayerRecordHandlerV1
from .admin_get_player_record_f4a5eb import AdminGetPlayerRecordsHandlerV1
from .admin_get_player_record_d622c9 import AdminGetPlayerRecordSizeHandlerV1
from .admin_post_player_publi_98e39e import AdminPostPlayerPublicRecordHandlerV1
from .admin_post_player_recor_6a96c8 import AdminPostPlayerRecordHandlerV1
from .admin_put_player_public_819faf import AdminPutPlayerPublicRecordHandlerV1
from .admin_put_player_record_a8195d import AdminPutPlayerRecordHandlerV1
from .admin_put_player_record_253e92 import AdminPutPlayerRecordsHandlerV1
from .admin_retrieve_player_records import AdminRetrievePlayerRecords
from .bulk_get_player_record__4627ec import BulkGetPlayerRecordSizeHandlerV1
from .list_player_record_handler_v1 import ListPlayerRecordHandlerV1
