# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: operation-init.j2

"""Auto-generated package that contains models used by the AccelByte Gaming Services Cloudsave Service."""

__version__ = "3.20.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .bulk_get_player_public__28e43c import BulkGetPlayerPublicRecordHandlerV1
from .delete_player_record_ha_3addde import DeletePlayerRecordHandlerV1
from .get_other_player_public_17685a import GetOtherPlayerPublicRecordHandlerV1
from .get_other_player_public_4438d8 import GetOtherPlayerPublicRecordKeyHandlerV1
from .get_player_public_recor_5ea27d import GetPlayerPublicRecordHandlerV1
from .get_player_record_handler_v1 import GetPlayerRecordHandlerV1
from .get_player_records_bulk_b10df3 import GetPlayerRecordsBulkHandlerV1
from .post_player_public_reco_b8589e import PostPlayerPublicRecordHandlerV1
from .post_player_record_handler_v1 import PostPlayerRecordHandlerV1
from .public_delete_player_pu_0cc8b5 import PublicDeletePlayerPublicRecordHandlerV1
from .put_player_public_recor_7928cf import PutPlayerPublicRecordHandlerV1
from .put_player_record_handler_v1 import PutPlayerRecordHandlerV1
from .retrieve_player_records import RetrievePlayerRecords
